store_criterion - Jumeaux
Author: tadashi-aikawa
Description: Check difference between two responses of API.

コンテンツにスキップ

# store_criterion

APIレスポンスを保存する基準を決定します。

##
free

細かな条件を指定してレスポンスの保存基準を決めることができます。

### Config

#### Definitions

Key | Type | Description | Example | Default
--- | --- | --- | --- | ---
when_any | str[] | 条件式 |
    '"2" in req.path'

when_anyで指定できるプロパティ

Template表記に対応しています。
プロパティは以下を使用できます。

key | Type | Description
--- | --- | ---
status | Status | ステータス
req | Request | リクエスト情報
res_one | Response | oneのレスポンス情報
res_other | Response | otherのレスポンス情報

Status

Name | Description
--- | ---
same | 結果を同一とみなす
different | 結果を同一ではないとみなす
failure | リクエストを失敗とみなす

#### Examples

##### pathが`/test`またはステータスがSameの結果は保存する

      store_criterion:
        - name: free
          config:
            when_any:
              - req.path == '/test'
              - status == 'same'